// Copyright © 2020 Amazon Web Services
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.opengroup.osdu.register.provider.aws.util;

import com.amazonaws.services.dynamodbv2.datamodeling.PaginatedQueryList;
import org.opengroup.osdu.core.aws.dynamodb.DynamoDBQueryHelper;

import org.opengroup.osdu.core.aws.dynamodb.DynamoDBQueryHelperV2;
import org.opengroup.osdu.register.ddms.model.Ddms;
import org.opengroup.osdu.register.provider.aws.ddms.DdmsDoc;
import org.opengroup.osdu.register.provider.aws.subscriber.KmsHelper;
import org.opengroup.osdu.register.provider.aws.subscriber.SubscriptionDoc;
import org.opengroup.osdu.register.subscriber.model.*;
import org.opengroup.osdu.register.utils.Constants;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;


@Component
public class DocUtil {
    @Autowired
    private KmsHelper kmsHelper;

    public List<Ddms> getDdmsList(DynamoDBQueryHelperV2 queryHelper, DdmsDoc gsiQuery) {

        PaginatedQueryList<DdmsDoc> results = queryHelper.queryByGSI(DdmsDoc.class, gsiQuery);
        List<Ddms> ddmsList = new ArrayList<Ddms>();
        if(results!=null) {
            for (DdmsDoc ddmsDoc : results) {
                ddmsList.add(DdmsDoc.mapto(ddmsDoc));
            }
        }
        return ddmsList;
    }

    public List<Subscription> getSubscriptionList(DynamoDBQueryHelperV2 queryHelper, SubscriptionDoc gsiQuery) {
        PaginatedQueryList<SubscriptionDoc> results = queryHelper.queryByGSI(SubscriptionDoc.class,gsiQuery);
        List<Subscription> subsList = new ArrayList<Subscription>();
        if(results!=null) {
            for (SubscriptionDoc subsDoc : results) {
                String secretValue = kmsHelper.decrypt(subsDoc.getSecretValue());
                Secret secret = createSecret(subsDoc.getSecretType(), secretValue);
                subsList.add(SubscriptionDoc.mapTo(subsDoc, secret));
            }
        }
        return subsList;
    }
    public Secret createSecret(String secretType, String secretValue)
    {
        Secret secret;
        if (secretType.equals(Constants.GSASecret)) {
            GsaSecret gsaSecret = new GsaSecret();
            String[] splitSecret = secretValue.split("`");
            gsaSecret.setValue(new GsaSecretValue(splitSecret[0], splitSecret[1]));
            secret = gsaSecret;
        } else {
            HmacSecret hmacSecret = new HmacSecret();
            hmacSecret.setValue(secretValue);
            secret = hmacSecret;
        }

        return secret;
    }

    public static String getHashKey() {
        return "id";
    }

}
