// Copyright © Microsoft Corporation
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.opengroup.osdu.register.provider.azure.subscriber;

import lombok.AllArgsConstructor;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;
import org.opengroup.osdu.register.subscriber.model.Subscription;

import java.sql.Timestamp;

@Getter
@Setter
@AllArgsConstructor
@NoArgsConstructor
public class SubscriptionDoc {
    private String id;
    private String name;
    private String description;
    private String topic;
    private String pushEndpoint;
    private String createdBy;
    private Timestamp createdOnEpoch;
    private String notificationId;
    private String secretType;
    private String secretValue;
    private String dataPartitionId;
    private String keyName;
    private String keyVersion;

    public SubscriptionDoc(Subscription subscription, String dataPartitionId){
        this.id = subscription.getId();
        this.name = subscription.getName();
        this.description = subscription.getDescription();
        this.topic = subscription.getTopic();
        this.pushEndpoint = subscription.getPushEndpoint();
        this.createdBy = subscription.getCreatedBy();
        this.createdOnEpoch = new Timestamp(System.currentTimeMillis());
        this.notificationId = subscription.getNotificationId();
        this.secretType = subscription.getSecret().getSecretType();
        this.secretValue = subscription.getSecret().toString();
        this.dataPartitionId = dataPartitionId;
    }
}
